@@ -193,7 +193,7 @@ class CustomCLIPWrapper(CLIPWrapper):
                  kl_coeff=1.0
                  ):
         root_dir = os.path.dirname(os.path.abspath(__file__))
-        with open(os.path.join(root_dir,'om_simple_encoder/configs/RN.yaml')) as fin:
+        with open(os.path.join(root_dir,'configs/RN.yaml')) as fin:
             config = yaml.safe_load(fin)['RN50']
         super().__init__('RN50', config, minibatch_size)
         del self.model.visual
